pywr.recorders.TotalHydroEnergyRecorder
=======================================

.. currentmodule:: pywr.recorders

.. autoclass:: TotalHydroEnergyRecorder

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~TotalHydroEnergyRecorder.after
      ~TotalHydroEnergyRecorder.aggregated_value
      ~TotalHydroEnergyRecorder.before
      ~TotalHydroEnergyRecorder.finish
      ~TotalHydroEnergyRecorder.load
      ~TotalHydroEnergyRecorder.register
      ~TotalHydroEnergyRecorder.reset
      ~TotalHydroEnergyRecorder.setup
      ~TotalHydroEnergyRecorder.unregister
      ~TotalHydroEnergyRecorder.values
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~TotalHydroEnergyRecorder.agg_func
      ~TotalHydroEnergyRecorder.children
      ~TotalHydroEnergyRecorder.comment
      ~TotalHydroEnergyRecorder.density
      ~TotalHydroEnergyRecorder.efficiency
      ~TotalHydroEnergyRecorder.energy_unit_conversion
      ~TotalHydroEnergyRecorder.epsilon
      ~TotalHydroEnergyRecorder.flow_unit_conversion
      ~TotalHydroEnergyRecorder.ignore_nan
      ~TotalHydroEnergyRecorder.is_constraint
      ~TotalHydroEnergyRecorder.is_objective
      ~TotalHydroEnergyRecorder.model
      ~TotalHydroEnergyRecorder.name
      ~TotalHydroEnergyRecorder.node
      ~TotalHydroEnergyRecorder.parents
      ~TotalHydroEnergyRecorder.turbine_elevation
      ~TotalHydroEnergyRecorder.water_elevation_parameter
   
   